from .accuracy import Accuracy
from .loss_and_logs import LossAndLogs
from .losses import AuxLosses, Losses
from .mean import Mean
from .mean_absolute_error import MeanAbsoluteError
from .mean_square_error import MeanSquareError
from .metric import Metric
from .metrics import AuxMetrics, Metrics
from .reduce import Reduce, Reduction

MAE = MeanAbsoluteError
MSE = MeanSquareError
